==> haskell-hit-0.6.3-29-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hit
version: 0.6.3
id: hit-0.6.3-KNmlSo1leCPINnDaARwSCM
key: hit-0.6.3-KNmlSo1leCPINnDaARwSCM
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hit
synopsis: Git operations in haskell
description:
    .
    An haskell implementation of git storage operations, allowing users
    to manipulate git repositories (read and write).
    .
    This implementation is fully interoperable with the main C implementation.
    .
    This is stricly only manipulating the git store (what'\''s inside the .git directory),
    and doesn'\''t do anything with the index or your working directory files.
    .
category: Development
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.Git Data.Git.Types Data.Git.Storage Data.Git.Storage.PackIndex
    Data.Git.Storage.Pack Data.Git.Storage.Object
    Data.Git.Storage.Loose Data.Git.Named Data.Git.Delta Data.Git.Ref
    Data.Git.Revision Data.Git.Repository Data.Git.Diff
hidden-modules: Data.Git.Internal Data.Git.Config
                Data.Git.Storage.FileReader Data.Git.Storage.FileWriter
                Data.Git.Storage.CacheFile Data.Git.Path Data.Git.WorkTree
abi: f5a1acd24c8c82442f56377c1d59777a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hit-0.6.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/hit-0.6.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/hit-0.6.3
hs-libraries: HShit-0.6.3-KNmlSo1leCPINnDaARwSCM
depends:
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    containers-0.5.7.1 cryptohash-0.11.9-KLIN16gW1mu17s2DuDaHoa
    hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    patience-0.1.1-B65C1NRz0al1tp0Blu1TPZ
    random-1.1-54KmMHXjttlERYcr1mvsAe
    system-fileio-0.3.16.3-EDef2a4Ximk1z04PLLp95q
    system-filepath-0.4.13.4-24DUGoIUqZu3MxGDhYLfCN
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
    zlib-bindings-0.1.1.5-C86Zxl67C8Q9nWCJyZSi5q
haddock-interfaces: /usr/share/doc/haskell-hit/html/hit.haddock
haddock-html: /usr/share/doc/haskell-hit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hit-0.6.3-31-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hit
version: 0.6.3
id: hit-0.6.3-CpofqamtC8c8Sy92SjvZ1F
key: hit-0.6.3-CpofqamtC8c8Sy92SjvZ1F
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hit
synopsis: Git operations in haskell
description:
    .
    An haskell implementation of git storage operations, allowing users
    to manipulate git repositories (read and write).
    .
    This implementation is fully interoperable with the main C implementation.
    .
    This is stricly only manipulating the git store (what'\''s inside the .git directory),
    and doesn'\''t do anything with the index or your working directory files.
    .
category: Development
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.Git Data.Git.Types Data.Git.Storage Data.Git.Storage.PackIndex
    Data.Git.Storage.Pack Data.Git.Storage.Object
    Data.Git.Storage.Loose Data.Git.Named Data.Git.Delta Data.Git.Ref
    Data.Git.Revision Data.Git.Repository Data.Git.Diff
hidden-modules: Data.Git.Internal Data.Git.Config
                Data.Git.Storage.FileReader Data.Git.Storage.FileWriter
                Data.Git.Storage.CacheFile Data.Git.Path Data.Git.WorkTree
abi: cda1a45725ec556b396b55b8a2bc0275
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hit-0.6.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/hit-0.6.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/hit-0.6.3
hs-libraries: HShit-0.6.3-CpofqamtC8c8Sy92SjvZ1F
depends:
    attoparsec-0.13.1.0-2ptg9LSVcb1at70Z7RWD3 base-4.9.0.0
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    containers-0.5.7.1 cryptohash-0.11.9-EjTCuGWNnJgLPmpaJ7EYxG
    hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr
    patience-0.1.1-B65C1NRz0al1tp0Blu1TPZ
    random-1.1-54KmMHXjttlERYcr1mvsAe
    system-fileio-0.3.16.3-CCI75LIhnelG6edCJIHU3h
    system-filepath-0.4.13.4-Hs7XtMIHiuY7X1m0lKul82
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
    zlib-bindings-0.1.1.5-C86Zxl67C8Q9nWCJyZSi5q
haddock-interfaces: /usr/share/doc/haskell-hit/html/hit.haddock
haddock-html: /usr/share/doc/haskell-hit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
